==> kara-uc-1.1.66.tgz: package/src/kara-uc/components/UCIntegral/index.js <==
import React, {Component} from 'react'
import {inject, observer} from "mobx-react"
import css from './index.scss'
import UCInfo from '../UCInfo/index'
import {action} from "mobx";
import tost from "kara-module-tost";

@inject('IntegralStore', 'ConfigStore')
@observer
class KaraIntegral extends Component {
  componentDidMount() {
    const {IntegralStore, ConfigStore} = this.props
    this.props.ConfigStore.config.httpAgent.get('/points/mine/get').then(
      res => {
        if (res && res.resultCode && res.resultCode === '000000') {
          IntegralStore.getIntegral(res)
        }
        else {
          tost({type: 'error', msg: '获取新商场积分失败', time: 4})
        }
      }
    )
    this.props.ConfigStore.config.httpAgent.get('/points/mine/get').then(
      res => {
        if (res && res.resultCode && res.resultCode === '000000') {
          IntegralStore.getAIIntegral(res)
        }
        else {
          tost({type: 'error', msg: '获取关爱通积分失败', time: 4})
        }
      }
    )
  }

  gotoStore = () => {
    const {ConfigStore} = this.props
    const {httpAgent} = ConfigStore.config;

    let winRef = window.open("", "_blank");//打开一个新的页面

    httpAgent.get('/points/ssoLogin/callback').then(action(
      res => {
        console.log("00000", res)
        if (res && res.resultCode && res.resultCode === '000000') {
          this.storeUrl = res.ngLoginUrl
          winRef.location = res.ngLoginUrl
        }
      }
    ))
  }

  render() {
    const {IntegralStore, lang} = this.props
    return (
      <div className={css.KaraIntegral}>
        <div>
          <div className='s-bg-page'>
            <div className='s-bg-score s-reverse'>
              <span>{lang.mallScore}</span>
              <span>{IntegralStore.pointer}<label>{lang.score}</label></span>
              <span>( 1{lang.yuan} = 100{lang.score} )</span>
            </div>
            <div className='s-bg-info'>
              <span className='btn btn-primary outline' onClick={this.gotoStore}>
                {lang.goShop}
              </span>
            </div>
          </div>

          <div className='s-bg-page'>
            <div className='s-bg-ai-score s-reverse'>
              <span>{lang.lovelySystemScore}</span>
              <span>{IntegralStore.pointerAI}<label>{lang.score}</label></span>
              <span>( 1{lang.yuan} = 1{lang.score} )</span>
            </div>
            <div className='s-bg-info'>
              <a className='btn btn-primary outline' href="https://officecloud.asiainfo.com/home/gojifensys"
                 target="_blank">
                {lang.goShop}
              </a>
            </div>
          </div>
        </div>
        <div>
          <label>{lang.notice}</label>
          <label>{lang.notice1}</label>
          <label>{lang.notice2}</label>
          <label>{lang.notice3}</label>
        </div>
      </div>
    )
  }
}

export default KaraIntegral

==> kara-uc-1.1.93.tgz: package/src/kara-uc/components/UCIntegral/index.js <==
import React, {Component} from 'react'
import {inject, observer} from "mobx-react"
import css from './index.scss'
import UCInfo from '../UCInfo/index'
import {action} from "mobx";
import {Tost} from "karaui";

@inject('IntegralStore', 'ConfigStore')
@observer
class KaraIntegral extends Component {
  componentDidMount() {
    const {IntegralStore, ConfigStore} = this.props
    this.props.ConfigStore.config.httpAgent.get('/points/mine/get').then(
      res => {
        if (res && res.resultCode && res.resultCode === '000000') {
          IntegralStore.getIntegral(res)
          IntegralStore.getAIIntegral(res)
        }
        else {
          Tost({type: 'error', msg: '获取积分失败', time: 4})
        }
      }
    )
  }

  gotoStore = () => {
    const {ConfigStore} = this.props
    const {httpAgent} = ConfigStore.config;

    let winRef = window.open("", "_blank");//打开一个新的页面

    httpAgent.get('/points/ssoLogin/callback').then(action(
      res => {
        console.log("00000", res)
        if (res && res.resultCode && res.resultCode === '000000') {
          this.storeUrl = res.ngLoginUrl
          winRef.location = res.ngLoginUrl
        }
      }
    ))
  }

  render() {
    const {IntegralStore, lang} = this.props
    console.log('积分',this.props)
    return (
      <div className={css.KaraIntegral}>
        <div>
          <div className='s-bg-page'>
            <div className='s-bg-score s-reverse'>
              <span>{lang.mallScore}</span>
              <span>{IntegralStore.pointer}<label>{lang.score}</label></span>
              <span>( 1{lang.yuan} = 100{lang.score} )</span>
            </div>
            <div className='s-bg-info'>
              <span className='btn btn-primary outline' onClick={this.gotoStore}>
                {lang.goShop}
              </span>
            </div>
          </div>

          <div className='s-bg-page'>
            <div className='s-bg-slicer-dot s-reverse'>
              <span>{lang.lovelySystemScore}</span>
              <span>{IntegralStore.pointerAI}<label>{lang.score}</label></span>
              <span>( 1{lang.yuan} = 1{lang.score} )</span>
            </div>
            <div className='s-bg-ai-score'>
              <a className='btn btn-primary outline' href="https://officecloud.asiainfo.com/home/gojifensys"
                 target="_blank">
                {lang.goShop}
              </a>
            </div>
          </div>
        </div>
        <div className={css.noticeLabel}>
          <label>{lang.notice}</label>
          <label>{lang.notice1}</label>
          <label>{lang.notice2}</label>
          <label>{lang.notice3}</label>
        </div>
      </div>
    )
  }
}

export default KaraIntegral
